@@ -1,11 +1,12 @@
 from vkwave.types.responses import *
+
 from ._category import Category
 from ._utils import get_params
 
 
 class App(Category):
     async def widgets_update(
-        self, code: str = None, type: str = None, return_raw_response: bool = False,
+        self, code: str, type: str, return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseOkResponse]:
         """
         :param code:
