@@ -1,4 +1,5 @@
 from vkwave.types.responses import *
+
 from ._category import Category
 from ._utils import get_params
 
@@ -6,20 +7,20 @@ from ._utils import get_params
 class Groups(Category):
     async def add_address(
         self,
-        group_id: int = None,
-        title: str = None,
-        address: str = None,
+        group_id: int,
+        title: str,
+        address: str,
+        country_id: int,
+        city_id: int,
+        latitude: int,
+        longitude: int,
+        return_raw_response: bool = False,
         additional_address: typing.Optional[str] = None,
-        country_id: int = None,
-        city_id: int = None,
         metro_id: typing.Optional[int] = None,
-        latitude: int = None,
-        longitude: int = None,
         phone: typing.Optional[str] = None,
         work_info_status: typing.Optional[str] = None,
         timetable: typing.Optional[str] = None,
         is_main_address: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsAddAddressResponse]:
         """
         :param group_id:
@@ -50,11 +51,11 @@ class Groups(Category):
 
     async def add_callback_server(
         self,
-        group_id: int = None,
-        url: str = None,
-        title: str = None,
-        secret_key: typing.Optional[str] = None,
+        group_id: int,
+        url: str,
+        title: str,
         return_raw_response: bool = False,
+        secret_key: typing.Optional[str] = None,
     ) -> typing.Union[dict, GroupsAddCallbackServerResponse]:
         """
         :param group_id:
@@ -76,10 +77,10 @@ class Groups(Category):
 
     async def add_link(
         self,
-        group_id: int = None,
-        link: str = None,
-        text: typing.Optional[str] = None,
+        group_id: int,
+        link: str,
         return_raw_response: bool = False,
+        text: typing.Optional[str] = None,
     ) -> typing.Union[dict, GroupsAddLinkResponse]:
         """
         :param group_id: - Community ID.
@@ -99,10 +100,7 @@ class Groups(Category):
         return result
 
     async def approve_request(
-        self,
-        group_id: int = None,
-        user_id: int = None,
-        return_raw_response: bool = False,
+        self, group_id: int, user_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -122,13 +120,13 @@ class Groups(Category):
 
     async def ban(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         end_date: typing.Optional[int] = None,
         reason: typing.Optional[int] = None,
         comment: typing.Optional[str] = None,
         comment_visible: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
@@ -152,12 +150,12 @@ class Groups(Category):
 
     async def create(
         self,
-        title: str = None,
+        title: str,
+        return_raw_response: bool = False,
         description: typing.Optional[str] = None,
         type: typing.Optional[str] = None,
         public_category: typing.Optional[int] = None,
         subtype: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsCreateResponse]:
         """
         :param title: - Community title.
@@ -179,10 +177,7 @@ class Groups(Category):
         return result
 
     async def delete_callback_server(
-        self,
-        group_id: int = None,
-        server_id: int = None,
-        return_raw_response: bool = False,
+        self, group_id: int, server_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
@@ -201,10 +196,7 @@ class Groups(Category):
         return result
 
     async def delete_link(
-        self,
-        group_id: int = None,
-        link_id: int = None,
-        return_raw_response: bool = False,
+        self, group_id: int, link_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -223,7 +215,7 @@ class Groups(Category):
         return result
 
     async def disable_online(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
@@ -242,7 +234,8 @@ class Groups(Category):
 
     async def edit(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         title: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
         screen_name: typing.Optional[str] = None,
@@ -287,7 +280,6 @@ class Groups(Category):
         secondary_section: typing.Optional[int] = None,
         country: typing.Optional[int] = None,
         city: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -350,8 +342,9 @@ class Groups(Category):
 
     async def edit_address(
         self,
-        group_id: int = None,
-        address_id: int = None,
+        group_id: int,
+        address_id: int,
+        return_raw_response: bool = False,
         title: typing.Optional[str] = None,
         address: typing.Optional[str] = None,
         additional_address: typing.Optional[str] = None,
@@ -364,7 +357,6 @@ class Groups(Category):
         work_info_status: typing.Optional[str] = None,
         timetable: typing.Optional[str] = None,
         is_main_address: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsEditAddressResponse]:
         """
         :param group_id:
@@ -396,12 +388,12 @@ class Groups(Category):
 
     async def edit_callback_server(
         self,
-        group_id: int = None,
-        server_id: int = None,
-        url: str = None,
-        title: str = None,
-        secret_key: typing.Optional[str] = None,
+        group_id: int,
+        server_id: int,
+        url: str,
+        title: str,
         return_raw_response: bool = False,
+        secret_key: typing.Optional[str] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
@@ -424,10 +416,10 @@ class Groups(Category):
 
     async def edit_link(
         self,
-        group_id: int = None,
-        link_id: int = None,
-        text: typing.Optional[str] = None,
+        group_id: int,
+        link_id: int,
         return_raw_response: bool = False,
+        text: typing.Optional[str] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -448,14 +440,14 @@ class Groups(Category):
 
     async def edit_manager(
         self,
-        group_id: int = None,
-        user_id: int = None,
+        group_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
         role: typing.Optional[str] = None,
         is_contact: typing.Optional[BaseBoolInt] = None,
         contact_position: typing.Optional[str] = None,
         contact_phone: typing.Optional[str] = None,
         contact_email: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -479,7 +471,7 @@ class Groups(Category):
         return result
 
     async def enable_online(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
@@ -498,13 +490,13 @@ class Groups(Category):
 
     async def get(
         self,
+        return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         filter: typing.Optional[typing.List[GroupsFilter]] = None,
         fields: typing.Optional[typing.List[GroupsFields]] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetResponse, GroupsGetExtendedResponse]:
         """
         :param user_id: - User ID.
@@ -532,14 +524,14 @@ class Groups(Category):
 
     async def get_addresses(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         address_ids: typing.Optional[typing.List[int]] = None,
         latitude: typing.Optional[int] = None,
         longitude: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[AddressesFields]] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetAddressesResponse]:
         """
         :param group_id: - ID or screen name of the community.
@@ -564,12 +556,12 @@ class Groups(Category):
 
     async def get_banned(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
         owner_id: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetBannedResponse]:
         """
         :param group_id: - Community ID.
@@ -592,10 +584,10 @@ class Groups(Category):
 
     async def get_by_id(
         self,
+        return_raw_response: bool = False,
         group_ids: typing.Optional[typing.List[str]] = None,
         group_id: typing.Optional[str] = None,
         fields: typing.Optional[typing.List[GroupsFields]] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetByIdResponse]:
         """
         :param group_ids: - IDs or screen names of communities.
@@ -615,7 +607,7 @@ class Groups(Category):
         return result
 
     async def get_callback_confirmation_code(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetCallbackConfirmationCodeResponse]:
         """
         :param group_id: - Community ID.
@@ -634,9 +626,9 @@ class Groups(Category):
 
     async def get_callback_servers(
         self,
-        group_id: int = None,
-        server_ids: typing.Optional[typing.List[int]] = None,
+        group_id: int,
         return_raw_response: bool = False,
+        server_ids: typing.Optional[typing.List[int]] = None,
     ) -> typing.Union[dict, GroupsGetCallbackServersResponse]:
         """
         :param group_id:
@@ -656,9 +648,9 @@ class Groups(Category):
 
     async def get_callback_settings(
         self,
-        group_id: int = None,
-        server_id: typing.Optional[int] = None,
+        group_id: int,
         return_raw_response: bool = False,
+        server_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, GroupsGetCallbackSettingsResponse]:
         """
         :param group_id: - Community ID.
@@ -678,9 +670,9 @@ class Groups(Category):
 
     async def get_catalog(
         self,
+        return_raw_response: bool = False,
         category_id: typing.Optional[int] = None,
         subcategory_id: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetCatalogResponse]:
         """
         :param category_id: - Category id received from [vk.com/dev/groups.getCatalogInfo|groups.getCatalogInfo].
@@ -700,12 +692,10 @@ class Groups(Category):
 
     async def get_catalog_info(
         self,
+        return_raw_response: bool = False,
         extended: typing.Optional[BaseBoolInt] = None,
         subcategories: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
-    ) -> typing.Union[
-        dict, GroupsGetCatalogInfoResponse, GroupsGetCatalogInfoExtendedResponse
-    ]:
+    ) -> typing.Union[dict, GroupsGetCatalogInfoResponse, GroupsGetCatalogInfoExtendedResponse]:
         """
         :param extended: - 1 – to return communities count and three communities for preview. By default: 0.
         :param subcategories: - 1 – to return subcategories info. By default: 0.
@@ -728,12 +718,12 @@ class Groups(Category):
 
     async def get_invited_users(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         name_case: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetInvitedUsersResponse]:
         """
         :param group_id: - Group ID to return invited users for.
@@ -756,10 +746,10 @@ class Groups(Category):
 
     async def get_invites(
         self,
+        return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetInvitesResponse, GroupsGetInvitesExtendedResponse]:
         """
         :param offset: - Offset needed to return a specific subset of invitations.
@@ -783,7 +773,7 @@ class Groups(Category):
         return result
 
     async def get_long_poll_server(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetLongPollServerResponse]:
         """
         :param group_id: - Community ID
@@ -801,7 +791,7 @@ class Groups(Category):
         return result
 
     async def get_long_poll_settings(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetLongPollSettingsResponse]:
         """
         :param group_id: - Community ID.
@@ -820,13 +810,13 @@ class Groups(Category):
 
     async def get_members(
         self,
+        return_raw_response: bool = False,
         group_id: typing.Optional[str] = None,
         sort: typing.Optional[str] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
         filter: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetMembersResponse]:
         """
         :param group_id: - ID or screen name of the community.
@@ -850,11 +840,11 @@ class Groups(Category):
 
     async def get_requests(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetRequestsResponse]:
         """
         :param group_id: - Community ID.
@@ -875,7 +865,7 @@ class Groups(Category):
         return result
 
     async def get_settings(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsGetSettingsResponse]:
         """
         :param group_id: - Community ID.
@@ -910,10 +900,7 @@ class Groups(Category):
         return result
 
     async def invite(
-        self,
-        group_id: int = None,
-        user_id: int = None,
-        return_raw_response: bool = False,
+        self, group_id: int, user_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -933,11 +920,11 @@ class Groups(Category):
 
     async def is_member(
         self,
-        group_id: str = None,
+        group_id: str,
+        return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         user_ids: typing.Optional[typing.List[int]] = None,
         extended: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsIsMemberResponse, GroupsIsMemberExtendedResponse]:
         """
         :param group_id: - ID or screen name of the community.
@@ -963,9 +950,9 @@ class Groups(Category):
 
     async def join(
         self,
+        return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
         not_sure: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - ID or screen name of the community.
@@ -984,7 +971,7 @@ class Groups(Category):
         return result
 
     async def leave(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - ID or screen name of the community.
@@ -1002,10 +989,7 @@ class Groups(Category):
         return result
 
     async def remove_user(
-        self,
-        group_id: int = None,
-        user_id: int = None,
-        return_raw_response: bool = False,
+        self, group_id: int, user_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -1025,10 +1009,10 @@ class Groups(Category):
 
     async def reorder_link(
         self,
-        group_id: int = None,
-        link_id: int = None,
-        after: typing.Optional[int] = None,
+        group_id: int,
+        link_id: int,
         return_raw_response: bool = False,
+        after: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -1049,7 +1033,8 @@ class Groups(Category):
 
     async def search(
         self,
-        q: str = None,
+        q: str,
+        return_raw_response: bool = False,
         type: typing.Optional[str] = None,
         country_id: typing.Optional[int] = None,
         city_id: typing.Optional[int] = None,
@@ -1058,7 +1043,6 @@ class Groups(Category):
         sort: typing.Optional[BaseBoolInt] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, GroupsSearchResponse]:
         """
         :param q: - Search query string.
@@ -1085,7 +1069,8 @@ class Groups(Category):
 
     async def set_callback_settings(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         server_id: typing.Optional[int] = None,
         api_version: typing.Optional[str] = None,
         message_new: typing.Optional[BaseBoolInt] = None,
@@ -1128,7 +1113,6 @@ class Groups(Category):
         user_block: typing.Optional[bool] = None,
         user_unblock: typing.Optional[bool] = None,
         lead_forms_new: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -1189,7 +1173,8 @@ class Groups(Category):
 
     async def set_long_poll_settings(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         enabled: typing.Optional[BaseBoolInt] = None,
         api_version: typing.Optional[str] = None,
         message_new: typing.Optional[BaseBoolInt] = None,
@@ -1231,7 +1216,6 @@ class Groups(Category):
         group_officers_edit: typing.Optional[bool] = None,
         user_block: typing.Optional[bool] = None,
         user_unblock: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id: - Community ID.
@@ -1291,9 +1275,9 @@ class Groups(Category):
 
     async def unban(
         self,
-        group_id: int = None,
-        owner_id: typing.Optional[int] = None,
+        group_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param group_id:
