@@ -1,4 +1,5 @@
 from vkwave.types.responses import *
+
 from ._category import Category
 from ._utils import get_params
 
@@ -6,10 +7,10 @@ from ._utils import get_params
 class Photos(Category):
     async def confirm_tag(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: str = None,
-        tag_id: int = None,
+        photo_id: str,
+        tag_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -30,10 +31,10 @@ class Photos(Category):
 
     async def copy(
         self,
-        owner_id: int = None,
-        photo_id: int = None,
-        access_key: typing.Optional[str] = None,
+        owner_id: int,
+        photo_id: int,
         return_raw_response: bool = False,
+        access_key: typing.Optional[str] = None,
     ) -> typing.Union[dict, PhotosCopyResponse]:
         """
         :param owner_id: - photo's owner ID
@@ -54,14 +55,14 @@ class Photos(Category):
 
     async def create_album(
         self,
-        title: str = None,
+        title: str,
+        return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
         description: typing.Optional[str] = None,
         privacy_view: typing.Optional[typing.List[str]] = None,
         privacy_comment: typing.Optional[typing.List[str]] = None,
         upload_by_admins_only: typing.Optional[bool] = None,
         comments_disabled: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosCreateAlbumResponse]:
         """
         :param title: - Album title.
@@ -86,8 +87,9 @@ class Photos(Category):
 
     async def create_comment(
         self,
+        photo_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
         from_group: typing.Optional[BaseBoolInt] = None,
@@ -95,7 +97,6 @@ class Photos(Category):
         sticker_id: typing.Optional[int] = None,
         access_key: typing.Optional[str] = None,
         guid: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosCreateCommentResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -122,9 +123,9 @@ class Photos(Category):
 
     async def delete(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
+        photo_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -144,9 +145,9 @@ class Photos(Category):
 
     async def delete_album(
         self,
-        album_id: int = None,
-        group_id: typing.Optional[int] = None,
+        album_id: int,
         return_raw_response: bool = False,
+        group_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param album_id: - Album ID.
@@ -166,9 +167,9 @@ class Photos(Category):
 
     async def delete_comment(
         self,
-        owner_id: typing.Optional[int] = None,
-        comment_id: int = None,
+        comment_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, PhotosDeleteCommentResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -188,15 +189,15 @@ class Photos(Category):
 
     async def edit(
         self,
+        photo_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
         caption: typing.Optional[str] = None,
         latitude: typing.Optional[int] = None,
         longitude: typing.Optional[int] = None,
         place_str: typing.Optional[str] = None,
         foursquare_id: typing.Optional[str] = None,
         delete_place: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -222,7 +223,8 @@ class Photos(Category):
 
     async def edit_album(
         self,
-        album_id: int = None,
+        album_id: int,
+        return_raw_response: bool = False,
         title: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
         owner_id: typing.Optional[int] = None,
@@ -230,7 +232,6 @@ class Photos(Category):
         privacy_comment: typing.Optional[typing.List[str]] = None,
         upload_by_admins_only: typing.Optional[bool] = None,
         comments_disabled: typing.Optional[bool] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param album_id: - ID of the photo album to be edited.
@@ -256,11 +257,11 @@ class Photos(Category):
 
     async def edit_comment(
         self,
+        comment_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        comment_id: int = None,
         message: typing.Optional[str] = None,
         attachments: typing.Optional[typing.List[str]] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -282,6 +283,7 @@ class Photos(Category):
 
     async def get(
         self,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         album_id: typing.Optional[str] = None,
         photo_ids: typing.Optional[typing.List[str]] = None,
@@ -292,7 +294,6 @@ class Photos(Category):
         photo_sizes: typing.Optional[BaseBoolInt] = None,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetResponse, PhotosGetExtendedResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photos. Use a negative value to designate a community ID.
@@ -324,6 +325,7 @@ class Photos(Category):
 
     async def get_albums(
         self,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         album_ids: typing.Optional[typing.List[int]] = None,
         offset: typing.Optional[int] = None,
@@ -331,7 +333,6 @@ class Photos(Category):
         need_system: typing.Optional[BaseBoolInt] = None,
         need_covers: typing.Optional[BaseBoolInt] = None,
         photo_sizes: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetAlbumsResponse]:
         """
         :param owner_id: - ID of the user or community that owns the albums.
@@ -356,9 +357,9 @@ class Photos(Category):
 
     async def get_albums_count(
         self,
+        return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetAlbumsCountResponse]:
         """
         :param user_id: - User ID.
@@ -378,6 +379,7 @@ class Photos(Category):
 
     async def get_all(
         self,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         offset: typing.Optional[BaseBoolInt] = None,
@@ -386,7 +388,6 @@ class Photos(Category):
         no_service_albums: typing.Optional[BaseBoolInt] = None,
         need_hidden: typing.Optional[BaseBoolInt] = None,
         skip_hidden: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetAllResponse, PhotosGetAllExtendedResponse]:
         """
         :param owner_id: - ID of a user or community that owns the photos. Use a negative value to designate a community ID.
@@ -416,12 +417,12 @@ class Photos(Category):
 
     async def get_all_comments(
         self,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
         album_id: typing.Optional[int] = None,
         need_likes: typing.Optional[BaseBoolInt] = None,
         offset: typing.Optional[BaseBoolInt] = None,
         count: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetAllCommentsResponse]:
         """
         :param owner_id: - ID of the user or community that owns the album(s).
@@ -444,10 +445,10 @@ class Photos(Category):
 
     async def get_by_id(
         self,
-        photos: typing.List[str] = None,
+        photos: typing.List[str],
+        return_raw_response: bool = False,
         extended: typing.Optional[BaseBoolInt] = None,
         photo_sizes: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetByIdResponse, PhotosGetByIdExtendedResponse]:
         """
         :param photos: - IDs separated with a comma, that are IDs of users who posted photos and IDs of photos themselves with an underscore character between such IDs. To get information about a photo in the group album, you shall specify group ID instead of user ID. Example: "1_129207899,6492_135055734, , -20629724_271945303"
@@ -472,11 +473,11 @@ class Photos(Category):
 
     async def get_chat_upload_server(
         self,
-        chat_id: int = None,
+        chat_id: int,
+        return_raw_response: bool = False,
         crop_x: typing.Optional[int] = None,
         crop_y: typing.Optional[int] = None,
         crop_width: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseGetUploadServerResponse]:
         """
         :param chat_id: - ID of the chat for which you want to upload a cover photo.
@@ -498,8 +499,9 @@ class Photos(Category):
 
     async def get_comments(
         self,
+        photo_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
         need_likes: typing.Optional[BaseBoolInt] = None,
         start_comment_id: typing.Optional[int] = None,
         offset: typing.Optional[BaseBoolInt] = None,
@@ -508,10 +510,7 @@ class Photos(Category):
         access_key: typing.Optional[str] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         fields: typing.Optional[typing.List[UsersFields]] = None,
-        return_raw_response: bool = False,
-    ) -> typing.Union[
-        dict, PhotosGetCommentsResponse, PhotosGetCommentsExtendedResponse
-    ]:
+    ) -> typing.Union[dict, PhotosGetCommentsResponse, PhotosGetCommentsExtendedResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
         :param photo_id: - Photo ID.
@@ -541,7 +540,7 @@ class Photos(Category):
         return result
 
     async def get_market_album_upload_server(
-        self, group_id: int = None, return_raw_response: bool = False,
+        self, group_id: int, return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseGetUploadServerResponse]:
         """
         :param group_id: - Community ID.
@@ -560,12 +559,12 @@ class Photos(Category):
 
     async def get_market_upload_server(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         main_photo: typing.Optional[BaseBoolInt] = None,
         crop_x: typing.Optional[int] = None,
         crop_y: typing.Optional[int] = None,
         crop_width: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetMarketUploadServerResponse]:
         """
         :param group_id: - Community ID.
@@ -587,9 +586,7 @@ class Photos(Category):
         return result
 
     async def get_messages_upload_server(
-        self,
-        peer_id: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
+        self, return_raw_response: bool = False, peer_id: typing.Optional[BaseBoolInt] = None,
     ) -> typing.Union[dict, PhotosGetMessagesUploadServerResponse]:
         """
         :param peer_id: - Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
@@ -608,9 +605,9 @@ class Photos(Category):
 
     async def get_new_tags(
         self,
+        return_raw_response: bool = False,
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetNewTagsResponse]:
         """
         :param offset: - Offset needed to return a specific subset of photos.
@@ -630,12 +627,12 @@ class Photos(Category):
 
     async def get_owner_cover_photo_upload_server(
         self,
-        group_id: int = None,
+        group_id: int,
+        return_raw_response: bool = False,
         crop_x: typing.Optional[int] = None,
         crop_y: typing.Optional[int] = None,
         crop_x2: typing.Optional[int] = None,
         crop_y2: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, BaseGetUploadServerResponse]:
         """
         :param group_id: - ID of community that owns the album (if the photo will be uploaded to a community album).
@@ -657,7 +654,7 @@ class Photos(Category):
         return result
 
     async def get_owner_photo_upload_server(
-        self, owner_id: typing.Optional[int] = None, return_raw_response: bool = False,
+        self, return_raw_response: bool = False, owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, BaseGetUploadServerResponse]:
         """
         :param owner_id: - identifier of a community or current user. "Note that community id must be negative. 'owner_id=1' – user, 'owner_id=-1' – community, "
@@ -676,10 +673,10 @@ class Photos(Category):
 
     async def get_tags(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
-        access_key: typing.Optional[str] = None,
+        photo_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
+        access_key: typing.Optional[str] = None,
     ) -> typing.Union[dict, PhotosGetTagsResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -700,9 +697,9 @@ class Photos(Category):
 
     async def get_upload_server(
         self,
+        return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
         album_id: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosGetUploadServerResponse]:
         """
         :param group_id: - ID of community that owns the album (if the photo will be uploaded to a community album).
@@ -722,15 +719,13 @@ class Photos(Category):
 
     async def get_user_photos(
         self,
+        return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         offset: typing.Optional[BaseBoolInt] = None,
         count: typing.Optional[BaseBoolInt] = None,
         extended: typing.Optional[BaseBoolInt] = None,
         sort: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
-    ) -> typing.Union[
-        dict, PhotosGetUserPhotosResponse, PhotosGetUserPhotosExtendedResponse
-    ]:
+    ) -> typing.Union[dict, PhotosGetUserPhotosResponse, PhotosGetUserPhotosExtendedResponse]:
         """
         :param user_id: - User ID.
         :param offset: - Offset needed to return a specific subset of photos. By default, '0'.
@@ -755,7 +750,7 @@ class Photos(Category):
         return result
 
     async def get_wall_upload_server(
-        self, group_id: typing.Optional[int] = None, return_raw_response: bool = False,
+        self, return_raw_response: bool = False, group_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, PhotosGetWallUploadServerResponse]:
         """
         :param group_id: - ID of community to whose wall the photo will be uploaded.
@@ -774,10 +769,10 @@ class Photos(Category):
 
     async def make_cover(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
-        album_id: typing.Optional[int] = None,
+        photo_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
+        album_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -798,10 +793,10 @@ class Photos(Category):
 
     async def move(
         self,
-        owner_id: typing.Optional[int] = None,
-        target_album_id: int = None,
-        photo_id: int = None,
+        target_album_id: int,
+        photo_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -822,14 +817,14 @@ class Photos(Category):
 
     async def put_tag(
         self,
+        photo_id: int,
+        user_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
-        user_id: int = None,
         x: typing.Optional[int] = None,
         y: typing.Optional[int] = None,
         x2: typing.Optional[int] = None,
         y2: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosPutTagResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -854,10 +849,10 @@ class Photos(Category):
 
     async def remove_tag(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
-        tag_id: int = None,
+        photo_id: int,
+        tag_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -878,11 +873,11 @@ class Photos(Category):
 
     async def reorder_albums(
         self,
+        album_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        album_id: int = None,
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the album.
@@ -904,11 +899,11 @@ class Photos(Category):
 
     async def reorder_photos(
         self,
+        photo_id: int,
+        return_raw_response: bool = False,
         owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
         before: typing.Optional[int] = None,
         after: typing.Optional[int] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -930,10 +925,10 @@ class Photos(Category):
 
     async def report(
         self,
-        owner_id: int = None,
-        photo_id: int = None,
-        reason: typing.Optional[BaseBoolInt] = None,
+        owner_id: int,
+        photo_id: int,
         return_raw_response: bool = False,
+        reason: typing.Optional[BaseBoolInt] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -954,10 +949,10 @@ class Photos(Category):
 
     async def report_comment(
         self,
-        owner_id: int = None,
-        comment_id: int = None,
-        reason: typing.Optional[BaseBoolInt] = None,
+        owner_id: int,
+        comment_id: int,
         return_raw_response: bool = False,
+        reason: typing.Optional[BaseBoolInt] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -978,9 +973,9 @@ class Photos(Category):
 
     async def restore(
         self,
-        owner_id: typing.Optional[int] = None,
-        photo_id: int = None,
+        photo_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, OkResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -1000,9 +995,9 @@ class Photos(Category):
 
     async def restore_comment(
         self,
-        owner_id: typing.Optional[int] = None,
-        comment_id: int = None,
+        comment_id: int,
         return_raw_response: bool = False,
+        owner_id: typing.Optional[int] = None,
     ) -> typing.Union[dict, PhotosRestoreCommentResponse]:
         """
         :param owner_id: - ID of the user or community that owns the photo.
@@ -1022,6 +1017,7 @@ class Photos(Category):
 
     async def save(
         self,
+        return_raw_response: bool = False,
         album_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
         server: typing.Optional[int] = None,
@@ -1030,7 +1026,6 @@ class Photos(Category):
         latitude: typing.Optional[BaseBoolInt] = None,
         longitude: typing.Optional[BaseBoolInt] = None,
         caption: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveResponse]:
         """
         :param album_id: - ID of the album to save photos to.
@@ -1055,12 +1050,7 @@ class Photos(Category):
         return result
 
     async def save_market_album_photo(
-        self,
-        group_id: int = None,
-        photo: str = None,
-        server: int = None,
-        hash: str = None,
-        return_raw_response: bool = False,
+        self, group_id: int, photo: str, server: int, hash: str, return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveMarketAlbumPhotoResponse]:
         """
         :param group_id: - Community ID.
@@ -1082,13 +1072,13 @@ class Photos(Category):
 
     async def save_market_photo(
         self,
+        photo: str,
+        server: int,
+        hash: str,
+        return_raw_response: bool = False,
         group_id: typing.Optional[int] = None,
-        photo: str = None,
-        server: int = None,
-        hash: str = None,
         crop_data: typing.Optional[str] = None,
         crop_hash: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveMarketPhotoResponse]:
         """
         :param group_id: - Community ID.
@@ -1112,10 +1102,10 @@ class Photos(Category):
 
     async def save_messages_photo(
         self,
-        photo: str = None,
+        photo: str,
+        return_raw_response: bool = False,
         server: typing.Optional[int] = None,
         hash: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveMessagesPhotoResponse]:
         """
         :param photo: - Parameter returned when the photo is [vk.com/dev/upload_files|uploaded to the server].
@@ -1135,7 +1125,7 @@ class Photos(Category):
         return result
 
     async def save_owner_cover_photo(
-        self, hash: str = None, photo: str = None, return_raw_response: bool = False,
+        self, hash: str, photo: str, return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveOwnerCoverPhotoResponse]:
         """
         :param hash: - Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
@@ -1155,10 +1145,10 @@ class Photos(Category):
 
     async def save_owner_photo(
         self,
+        return_raw_response: bool = False,
         server: typing.Optional[str] = None,
         hash: typing.Optional[str] = None,
         photo: typing.Optional[str] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveOwnerPhotoResponse]:
         """
         :param server: - parameter returned after [vk.com/dev/upload_files|photo upload].
@@ -1179,15 +1169,15 @@ class Photos(Category):
 
     async def save_wall_photo(
         self,
+        photo: str,
+        return_raw_response: bool = False,
         user_id: typing.Optional[int] = None,
         group_id: typing.Optional[int] = None,
-        photo: str = None,
         server: typing.Optional[int] = None,
         hash: typing.Optional[str] = None,
         latitude: typing.Optional[BaseBoolInt] = None,
         longitude: typing.Optional[BaseBoolInt] = None,
         caption: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSaveWallPhotoResponse]:
         """
         :param user_id: - ID of the user on whose wall the photo will be saved.
@@ -1213,6 +1203,7 @@ class Photos(Category):
 
     async def search(
         self,
+        return_raw_response: bool = False,
         q: typing.Optional[str] = None,
         lat: typing.Optional[BaseBoolInt] = None,
         long: typing.Optional[BaseBoolInt] = None,
@@ -1222,7 +1213,6 @@ class Photos(Category):
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         radius: typing.Optional[BaseBoolInt] = None,
-        return_raw_response: bool = False,
     ) -> typing.Union[dict, PhotosSearchResponse]:
         """
         :param q: - Search query string.
