@@ -1,6 +1,6 @@
 from asyncio import iscoroutinefunction
 from inspect import isawaitable, isfunction
-from typing import Any
+from typing import Any, Optional
 
 from vkwave.bots.core.dispatching.cast.default import DefaultCaster
 
@@ -8,21 +8,16 @@ from .base import AsyncFuncFilter, BaseFilter, SyncFuncFilter
 
 
 class FilterCaster(DefaultCaster[BaseFilter]):
-    def cast(self, something: Any):
-
-        av_cast = super().cast(something)
-        if av_cast:
-            return av_cast
-
-        filter: BaseFilter
+    def default(self, something: Any) -> Optional[BaseFilter]:
+        filter: Optional[BaseFilter]
         if iscoroutinefunction(something) or isawaitable(something):
             filter = AsyncFuncFilter(something)
-            return filter
-        if isfunction(something):
+        elif isfunction(something):
             filter = SyncFuncFilter(something)
-            return filter
+        else:
+            filter = None
 
-        raise NotImplementedError("There is not caster for this type")
+        return filter
 
 
 caster = FilterCaster()
