@@ -1,6 +1,6 @@
 from asyncio import iscoroutinefunction
 from inspect import isawaitable, isfunction
-from typing import Any
+from typing import Any, Optional
 
 from vkwave.bots.core.dispatching.cast.default import DefaultCaster
 
@@ -8,22 +8,18 @@ from .callback import AsyncFuncCallback, BaseCallback, SyncFuncCallback
 
 
 class CallbackCaster(DefaultCaster[BaseCallback]):
-    def cast(self, something: Any) -> BaseCallback:
-        av_cast = super().cast(something)
-        if av_cast:
-            return av_cast
-
-        cb: BaseCallback
+    def default(self, something: Any) -> Optional[BaseCallback]:
+        cb: Optional[BaseCallback]
         if iscoroutinefunction(something) or isawaitable(something):
             cb = AsyncFuncCallback(something)
-            return cb
-        if isfunction(something):
+        elif isfunction(something):
             cb = SyncFuncCallback(something)
-            return cb
-        if isinstance(something, str):
-            return SyncFuncCallback(lambda event: something)
+        elif isinstance(something, str):
+            cb = SyncFuncCallback(lambda event: something)
+        else:
+            cb = None
 
-        raise NotImplementedError("There is no cast for this type")
+        return cb
 
 
 caster = CallbackCaster()
